---
icon: material/file-code
---

# Encodings

In this section we show a basic documentation of our encoding in the form of a docstring of the used predicates.

::: src/coomsuite/encodings/encoding-base-clingo-show.lp
    handler: asp
    options:
        encodings: true
        predicate_table: true
        dependency_graph: true
        glossary: true
